@@ -79,9 +79,15 @@ class PathProxy2:
     def getTrainCKPT(projectid,modelid):
         return os.path.join(PathProxy2.app_path,"Projects",projectid,modelid,"TrainSaver", "save.ckpt")
     
+    def getTrainCKPTPath(projectid,modelid):
+        return os.path.join(PathProxy2.app_path,"Projects",projectid,modelid,"TrainSaver","model.epoch")
+    
     def getValidCKPT(projectid,modelid):
         return os.path.join(PathProxy2.app_path,"Projects",projectid,modelid,"ValidSaver", "save.ckpt")
     
+    def getValidCKPTPath(projectid,modelid):
+        return os.path.join(PathProxy2.app_path,"Projects",projectid,modelid,"ValidSaver","model.epoch")
+    
     def getProjectNames():
         return os.listdir(os.path.join(PathProxy2.app_path,"Projects"))
     
