@@ -123,7 +123,7 @@ class MACallBack2(Callback):
     
     def saveModelEpoch(modelpath,epoch):
         f = open(modelpath,'w')
-        f.write(str(epoch+self.epcho))
+        f.write(str(epoch))
         f.close()
         pass
     
@@ -171,7 +171,7 @@ class MACallBack2(Callback):
                 self.saveModel(trainmodel)
                 self.max_train_acc = train_mean
                 
-                MACallBack2.saveModelEpoch(trainmodelpath,epoch)
+                MACallBack2.saveModelEpoch(trainmodelpath,epoch+self.epcho)
             
             if valid_mean > max_valid_acc:
                 #save model here
